pub enum CorrelationError {
InvalidIncident(Error),
UnknownAffectedNode(String),
UnknownEdgeTarget(String),
}Expand description
Anything that can go wrong inside the crate.
Variants
InvalidIncident(Error)
Failed to deserialise the incident card.
UnknownAffectedNode(String)
An affected_documents entry pointed at a node not in the graph.
UnknownEdgeTarget(String)
An edge tried to point at a node id that wasn’t added first.